@@ -5,6 +5,17 @@ compas.numerical
 
 .. currentmodule:: compas.numerical
 
+.. note::
+
+    For many functions, multiple implementations are available using various backends.
+    If no backend is specified, the function is assumed to be implemented in pure Python.
+    The suffix `_numpy` indicates that the function uses Numpy and/or Scipy.
+    Some of the other possibilities are `_alglib`, `_cpp`, `_matlab`, `_sympy`.
+
+    On most platforms, all variants are directly available.
+    In Rhino, only the pure Python and the `_alglib` variants can be used directly.
+    All others have to be accessed through an `XFunc` or an `RPC` service.
+
 
 Solvers
 =======
@@ -13,15 +24,15 @@ Solvers
     :toctree: generated/
     :nosignatures:
 
-    descent
+    descent_numpy
     devo_numpy
     dr
     dr_numpy
     drx_numpy
+    fd_alglib
+    fd_cpp
     fd_numpy
     ga
-    lma
-    mma
     moga
     pca_numpy
     topop2d_numpy
@@ -101,11 +112,15 @@ from .matrices import *
 from .operators import *
 from .utilities import *
 
-from .solvers import *
-from .algorithms import *
-
+from .descent import *
+from .devo import *
 from .dr import *
 from .drx import *
 from .fd import *
+from .ga import *
+# from .lma import *
+# from .mma import *
+from .pca import *
+from .topop import *
 
 __all__ = [name for name in dir() if not name.startswith('_')]
