@@ -6,12 +6,6 @@ from collections import deque
 from compas.utilities import pairwise
 
 
-__author__     = ['Tom Van Mele <vanmelet@ethz.ch>', ]
-__copyright__  = 'Copyright 2014, Block Research Group - ETH Zurich'
-__license__    = 'MIT License'
-__email__      = 'vanmelet@ethz.ch'
-
-
 __all__ = [
     'depth_first_ordering',
     'depth_first_tree',
